from django.contrib import admin
from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.contrib.auth.forms import AdminPasswordChangeForm
from django.contrib.auth.models import Group
from django.contrib.auth import get_user_model
import inspect
import traceback

# Register your models here.
from . import models

class CustomUserAdmin(UserAdmin):
    list_display = ('username', 'last_name', 'first_name')
    search_fields = list_display
    moderator_fields = ['username', 'first_name', 'last_name']
    superuser_fields = ['groups', 'is_staff']

    def has_delete_permission(self, request, obj=None):
        if not request.user.is_superuser and obj and (obj.is_superuser or obj.is_staff):
            return False
        return True

    def get_form(self, request, obj=None, **kwargs):
        form = super().get_form(request, obj, **kwargs)
        is_superuser = request.user.is_superuser

        if not is_superuser:
            for field in ['is_staff']:
                if field in form.base_fields:
                    form.base_fields[field].disabled = True
                    del form.base_fields[field]

        return form

    def get_readonly_fields(self, request, obj=None):
        readonly = ['date_joined', 'last_login']
        if not request.user.is_superuser:
            readonly += ['username', 'groups', 'is_superuser', 'is_staff', 'user_permissions']
            if obj and (obj.is_superuser or obj.is_staff):
                readonly += ['is_active', 'first_name', 'last_name', 'email']
        return readonly

    def change_password_form(self, user, *args, **kwargs):
        return AdminPasswordChangeForm(user, *args, **kwargs)

admin.site.register(models.User, CustomUserAdmin)
