from django import forms
from django.core.exceptions import ValidationError
from django.contrib.auth import get_user_model
from django.conf import settings
import re

class LoginForm(forms.Form):
    username = forms.CharField(widget=forms.TextInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))
    password = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))

class RegisterForm(forms.Form):
    username = forms.CharField(widget=forms.TextInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))
    email = forms.CharField(widget=forms.TextInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))
    email_domain = forms.ChoiceField(widget=forms.Select(attrs={'class': 'w3-input w3-border w3-light-grey'}), choices=[(None, "Please select email domain")] + list(zip(settings.EMAIL_DOMAINS, settings.EMAIL_DOMAINS)), required=True)

    def clean(self):
        cleaned_data = super().clean()

        cleaned_data["email"] = (cleaned_data["email"] + cleaned_data["email_domain"]).lower()
        del cleaned_data["email_domain"]

        username = cleaned_data["username"]
        email = cleaned_data["email"]

        if email in settings.EMAIL_BLACKLIST:
            raise ValidationError("Given E-Mail address has been blacklisted to avoid abuse.\nPlease contact admin@fslab.de for account creation.")
        elif not re.match(r"^[a-z0-9]+$", username):
            raise ValidationError("Username can only consist of lowercase letters and numbers")
        elif username.endswith("2s") or username.endswith("2m") or username.endswith("2a"):
            raise ValidationError("Users of the Department of Computer Science can login using their normal email credentials!")
        elif get_user_model().objects.filter(username=username):
            raise ValidationError("User with that username already exists.")
        elif get_user_model().objects.filter(email=email):
            raise ValidationError("User with this Email already exists.")

        return cleaned_data

class PasswordResetForm(forms.Form):
    password = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))
    confirm = forms.CharField(widget=forms.PasswordInput(attrs={'class': 'w3-input w3-border w3-light-grey'}))

