from django.shortcuts import render, redirect, get_object_or_404
from .forms import LoginForm, RegisterForm, PasswordResetForm
from django.contrib.auth import get_user_model
from django.contrib.auth import authenticate, login, logout
from django.core.mail import send_mail
from django.core.mail import EmailMessage
import traceback

def logout_view(request):
    if request.user.is_authenticated:
        logout(request)
    return render(request, "accounts/logged_out.html")

def activate_view(request, activation_code):
    if request.user.is_authenticated:
        return redirect(request.GET.get("next") if request.GET.get("next") is not None else "/")

    user = get_object_or_404(get_user_model(), is_activated=False, activation_code=activation_code)

    if request.method == "POST":
        form = PasswordResetForm(request.POST)
        if form.is_valid():
            user.is_activated = True
            user.activation_code = ""
            user.set_password(form.cleaned_data['password'])
            user.save()
            login(request, user, backend='django.contrib.auth.backends.ModelBackend')

            for admin in get_user_model().objects.filter(is_superuser=True, is_active=True):
                if not admin.admin_mails:
                    continue
                msg = "Hello %s,\n\na new account has been activated:\n\nUser: %s\nE-Mail: %s" % (admin.first_name, user.username, user.email)
                email = EmailMessage('lectures.fslab.de – Admin – Account activated', msg, to=[admin.email])
                try:
                    email.send()
                except:
                    traceback.print_exc()
                    pass

            return redirect("/")
    else:
        form = PasswordResetForm()

    return render(request, "accounts/password.html", {'title': 'Activate account', 'form': form})

def register_view(request):
    if request.user.is_authenticated:
        return redirect(request.GET.get("next") if request.GET.get("next") is not None else "/")

    created = False
    if request.method == 'POST':
        form = RegisterForm(request.POST)
        if form.is_valid():
            user = get_user_model()()
            user.is_activated = False
            user.is_staff = False
            user.is_superuser = False
            user.username = form.cleaned_data["username"]
            user.email = form.cleaned_data["email"]

            msg = "Hello %s,\n\nplease go to https://lectures.fslab.de/accounts/activate/%s to activate your account and set your password.\n\nThanks,\nlectures.fslab.de" % (user.username, user.activation_code)
            email = EmailMessage('lectures.fslab.de – Account activation', msg, to=[user.email])
            email.send()
            user.save()
            created = True
    else:
        form = RegisterForm()

    return render(request, "accounts/register.html", {'form': form, 'created': created})

def login_view(request):
    if request.user.is_authenticated:
        return redirect(request.GET.get("next") if request.GET.get("next") is not None else "/")

    if request.method == 'POST':
        form = LoginForm(request.POST)
        if form.is_valid():
            try:
                user = authenticate(username=form.cleaned_data["username"], password=form.cleaned_data["password"])
                if user and user.is_active and user.is_activated:
                    login(request, user)
                    return redirect(request.GET.get("next") if request.GET.get("next") is not None else "/")
                elif user and (not user.is_activated or not user.is_active):
                    form.add_error(None, "User has not been activated.")
                else:
                    form.add_error(None, "Please enter a correct username and password.\nNote that both fields may be case-sensitive.")
            except:
                form.add_error(None, "An exception occured during authentication.\nPlease try again later or contact admin@fslab.de.")
                traceback.print_exc()
    else:
        form = LoginForm()

    return render(request, "accounts/login.html", {'form': form})


