from django.contrib import admin
from django import forms
from django.utils.html import format_html
from django.forms import widgets

from .models import Term, Course, Video, VideoQuality, CourseAttachment, VideoAttachment, Worker, CDNHost
from .api import get_worker_script

# cdnhost
class CDNHostAdmin(admin.ModelAdmin):
    list_display = ('name', 'enabled', 'healthy', 'last_seen')

admin.site.register(CDNHost, CDNHostAdmin)


# workers
class WorkerAdmin(admin.ModelAdmin):
    list_display = ('name', 'enabled', 'last_seen', 'notes')

admin.site.register(Worker, WorkerAdmin)


# terms
class TermAdmin(admin.ModelAdmin):
    pass
admin.site.register(Term, TermAdmin)


# video subformats
class VideoQualityAdmin(admin.ModelAdmin):
    pass
admin.site.register(VideoQuality, VideoQualityAdmin)


# videos
class VideoAttachmentAdmin(admin.TabularInline):
    model = VideoAttachment

class VideoAdmin(admin.ModelAdmin):
    def not_failed(self, obj):
        return not obj.failed

    def resolution(self, obj):
        return "{}x{}".format(obj.width, obj.height)

    list_display = ["name", "views", "state", "course", "resolution", "length", "worker", "not_failed"]
    inlines = [VideoAttachmentAdmin]

admin.site.register(Video, VideoAdmin)


# courses
class CourseAttachmentAdmin(admin.TabularInline):
    model = CourseAttachment

class CourseAdmin(admin.ModelAdmin):
    def lecturer_names(self):
        return ", ".join(["{} {}".format(l.first_name, l.last_name) if (l.first_name or l.last_name) else l.username for l in self.lecturers.all()])

    def student_count(self):
        return len(self.get_students())

    def video_count(self):
        return len(self.video_set.all())

    autocomplete_fields = ["lecturers", "owner"]
    list_display = ('title', 'owner', 'views', 'term', lecturer_names, student_count, video_count)
    inlines = [CourseAttachmentAdmin]
admin.site.register(Course, CourseAdmin)

