# Generated by Django 3.0.5 on 2020-04-10 00:01

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import videos.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='CDNHost',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=200)),
                ('enabled', models.BooleanField(default=True)),
                ('healthy', models.BooleanField(default=True)),
                ('key', models.CharField(default=videos.models.random_key_50, max_length=50, unique=True)),
                ('url', models.TextField(max_length=200)),
                ('last_seen', models.DateTimeField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='Course',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('students', models.TextField(blank=True, null=True, verbose_name='Whitelisted students (optional; usernames separated by whitespace and/or commata)')),
                ('views', models.IntegerField(default=0)),
                ('key', models.CharField(default=videos.models.random_key_20, max_length=30, unique=True)),
                ('title', models.CharField(max_length=50, verbose_name='Course Name')),
                ('description', models.TextField(blank=True, verbose_name='Course Description')),
                ('accessibility', models.CharField(choices=[('closed', 'Only accessible by whitelisted students and lecturers'), ('internal', 'Accessible by any student and lecturer'), ('public', 'Accessible by anybody')], default='closed', max_length=8, verbose_name='Access restrictions')),
                ('hidden', models.BooleanField(default=True, verbose_name='Hide Course')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('lecturers', models.ManyToManyField(blank=True, related_name='teaching', to=settings.AUTH_USER_MODEL)),
                ('owner', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='owns', to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='Term',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=1000)),
                ('year', models.IntegerField(default=2020)),
                ('archived', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Video',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.CharField(default='Waiting for processing worker... (This will normaly take only a few seconds)', max_length=100, verbose_name='State')),
                ('log', models.TextField(blank=True, null=True, verbose_name='Log')),
                ('failed', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('width', models.IntegerField(blank=True, null=True)),
                ('height', models.IntegerField(blank=True, null=True)),
                ('key', models.CharField(default=videos.models.random_key_20, max_length=30, unique=True)),
                ('views', models.IntegerField(default=0)),
                ('name', models.CharField(blank=True, max_length=1000)),
                ('description', models.TextField(blank=True)),
                ('length', models.DecimalField(blank=True, decimal_places=3, max_digits=10, null=True)),
                ('original', models.FileField(upload_to=videos.models.Video.original_upload_path)),
                ('masterfile', models.FileField(blank=True, null=True, upload_to=videos.models.Video.master_upload_path)),
                ('thumbnail', models.ImageField(blank=True, null=True, upload_to=videos.models.Video.thumb_upload_path)),
                ('subtitles', models.FileField(blank=True, null=True, upload_to=videos.models.Video.subtitles_upload_path)),
                ('course', models.ForeignKey(on_delete=videos.models.Course, to='videos.Course')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Worker',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=50)),
                ('key', models.CharField(default=videos.models.random_key_50, max_length=50, unique=True)),
                ('enabled', models.BooleanField(default=True)),
                ('notes', models.TextField(blank=True, null=True)),
                ('last_seen', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='VideoQuality',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('state', models.CharField(default='Waiting for processing worker... (This will normaly take only a few seconds)', max_length=100, verbose_name='State')),
                ('log', models.TextField(blank=True, null=True, verbose_name='Log')),
                ('failed', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('width', models.IntegerField(blank=True, null=True)),
                ('height', models.IntegerField(blank=True, null=True)),
                ('command', models.TextField(blank=True, null=True)),
                ('quality', models.CharField(max_length=20)),
                ('videofile', models.FileField(upload_to=videos.models.VideoQuality.upload_path)),
                ('video', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='videos.Video')),
                ('worker', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='videos.Worker')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='VideoAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=1000)),
                ('description', models.TextField(blank=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('attachment', models.FileField(upload_to=videos.models.VideoAttachment.upload_path)),
                ('video', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='videos.Video')),
            ],
        ),
        migrations.AddField(
            model_name='video',
            name='worker',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='videos.Worker'),
        ),
        migrations.CreateModel(
            name='CourseAttachment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(blank=True, max_length=1000)),
                ('description', models.TextField(blank=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('attachment', models.FileField(upload_to=videos.models.CourseAttachment.upload_path)),
                ('course', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='videos.Course')),
            ],
        ),
        migrations.AddField(
            model_name='course',
            name='term',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='videos.Term'),
        ),
    ]
